{% extends 'allianceauth/base-bs5.html' %}
{% load humanize %}
{% load i18n %}

{% block page_title %}{{ app_title }}{% endblock %}

{% block header_nav_brand %}{{ app_title }}{% endblock %}

{% block content %}
    {% include "framework/header/page-header.html" with title=page_title %}

    {% block details %}{% endblock %}
{% endblock %}
